# Release

For releasing `cosapp_creator`, please check the following items are fulfilled:

1. Documentation is up-to-date:

- [ ] [CHANGELOG.md](CHANGELOG.md)

2. Update dependencies in [pyproject.toml](pyproject.toml)

- [ ] Update `cosapp` version

3. Version bumped

- [ ] [package.json](package.json)
- [ ] [Git tag](vX.Y.Z)
